def_error (SUCCESS)
def_error (DEVICE_NOT_FOUND)
def_error (DEVICE_NOT_AVAILABLE)
def_error (COMPILER_NOT_AVAILABLE)
def_error (MEM_OBJECT_ALLOCATION_FAILURE)
def_error (OUT_OF_RESOURCES)
def_error (OUT_OF_HOST_MEMORY)
def_error (PROFILING_INFO_NOT_AVAILABLE)
def_error (MEM_COPY_OVERLAP)
def_error (IMAGE_FORMAT_MISMATCH)
def_error (IMAGE_FORMAT_NOT_SUPPORTED)
def_error (BUILD_PROGRAM_FAILURE)
def_error (MAP_FAILURE)
def_error (MISALIGNED_SUB_BUFFER_OFFSET)
def_error (EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)
def_error (INVALID_VALUE)
def_error (INVALID_DEVICE_TYPE)
def_error (INVALID_PLATFORM)
def_error (INVALID_DEVICE)
def_error (INVALID_CONTEXT)
def_error (INVALID_QUEUE_PROPERTIES)
def_error (INVALID_COMMAND_QUEUE)
def_error (INVALID_HOST_PTR)
def_error (INVALID_MEM_OBJECT)
def_error (INVALID_IMAGE_FORMAT_DESCRIPTOR)
def_error (INVALID_IMAGE_SIZE)
def_error (INVALID_SAMPLER)
def_error (INVALID_BINARY)
def_error (INVALID_BUILD_OPTIONS)
def_error (INVALID_PROGRAM)
def_error (INVALID_PROGRAM_EXECUTABLE)
def_error (INVALID_KERNEL_NAME)
def_error (INVALID_KERNEL_DEFINITION)
def_error (INVALID_KERNEL)
def_error (INVALID_ARG_INDEX)
def_error (INVALID_ARG_VALUE)
def_error (INVALID_ARG_SIZE)
def_error (INVALID_KERNEL_ARGS)
def_error (INVALID_WORK_DIMENSION)
def_error (INVALID_WORK_GROUP_SIZE)
def_error (INVALID_WORK_ITEM_SIZE)
def_error (INVALID_GLOBAL_OFFSET)
def_error (INVALID_EVENT_WAIT_LIST)
def_error (INVALID_EVENT)
def_error (INVALID_OPERATION)
def_error (INVALID_GL_OBJECT)
def_error (INVALID_BUFFER_SIZE)
def_error (INVALID_MIP_LEVEL)
def_error (INVALID_GLOBAL_WORK_SIZE)
def_error (INVALID_PROPERTY)
